# gh-notifier

[![Join the chat at https://gitter.im/kshitij10496/gh-scrapper](https://badges.gitter.im/kshitij10496/gh-scrapper.svg)](https://gitter.im/kshitij10496/gh-scrapper?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

> A Desktop notifier for all your "social" GitHub notifications.

The project is in pre-alpha stage and is under heavy developement.

### Features
---------------
Currently, it notifies a user when:

- [x] someone follows them
- [x] someone stars/forks/watches their repository

### Contributing
------------------
Please feel free to report any discrepancy on the [Issues Tracker]().
If you have any feature requests, comment on this [thread]().
I will try to implement them.
More so, feel free to open a Pull Request.

#### LICENSE : MIT
